import {FC, useEffect, useState} from "react";
import {Image, ScrollView, View} from "@tarojs/components";
import {HomeApi} from "@/api";
import Taro, {useReachBottom} from "@tarojs/taro";
import styles from './health.module.scss'
import play from '@/static/img/play.png'
import Empty from "@/components/empty/empty";

const Health: FC = () => {
  const [page, setPage] = useState(1)
  const [data, setData] = useState<Health[]>([])
  const [total, setTotal] = useState(0)

  async function getData(page: number) {
    const res = await HomeApi.health(page, 10)
    setData(res.data)
    setTotal(res.total)
  }

  useReachBottom(() => {
    data.length < total && setPage(page + 1)
  })

  useEffect(() => {
    getData(page)
  }, [page])

  function jump(health: Health) {
    HomeApi.healthSetPlay(health.id)
    Taro.navigateTo({url: `/pages/preview/videoFull/videoFull?url=${health.resource.url}&poster=${health.url_path}&title=${health.title}`})
  }

  return (
    <ScrollView>
      <View className={styles.container}>
        {
          data.length > 0
            ? data.map(d => <View key={d.id} className={styles.health} onClick={() => jump(d)}>
              <Image src={d.url_path} mode='widthFix' lazyLoad fadeIn/>
              <Image src={play} className={styles.play} mode='aspectFit'/>
              <View className='text-ellipsis-2 m-2 text-dark'>{d.title}</View>
              <View className='font-26  text-muted mx-2 mb-2'>{d.video_view}观看</View>
            </View>)
            : <Empty name='暂无数据'/>
        }
      </View>
    </ScrollView>
  )
}

export default Health
